@@ -11,16 +11,17 @@ import json
 import logging
 from functools import wraps
 from getpass import getpass
-from typing import List, Dict, Any
+from pathlib import Path
+from typing import List, Dict, Any, Optional
 
 from .progress import CliProgress
-from .. import __version__
+from .. import VERSION_WITH_DEPS
 from ..utils.config import Config, load_projects, load_config, \
     config_to_dict
 from .cli_builder import rename, return_to_stdout, partial, lazy_partial, \
     Subcommands, Subcommand, SubcommandGroup, decorate, block, set_default
 from ..utils.log import exception_to_message, add_stream_handler_to_logger, \
-    add_rotating_file_handler_to_logger
+    add_rotating_file_handler_to_logger, create_logger
 from ..workflows.config import create as create_config
 from ..workflows.transfer import transfer as workflows_transfer
 from ..workflows.decrypt import decrypt as workflows_decrypt
@@ -32,6 +33,8 @@ from ..core.versioncheck import check_version
 from ..core.error import UserError
 from .. import URL_READTHEDOCS, URL_GITLAB_ISSUES
 
+logger = create_logger(__name__)
+
 
 def parse_dict(s):
     return json.loads(s)
@@ -48,30 +51,36 @@ def parse_protocol_args(s):
 def two_factor_cli_prompt():
     return input("Verification code: ")
 
-@block("passphrase")
+
+@exception_to_message(FileNotFoundError, logger)
+def get_passphrase_from_file_or_prompt(passphrase_file: Optional[str]) -> str:
+    if passphrase_file:
+        return Path(passphrase_file).read_text().strip()
+    return getpass("Please enter your gpg private key password:")
+
+
 @wraps(workflows_encrypt)
-def encrypt(*args, config: Config, dry_run: bool, **kwargs):
+def encrypt(*args, config: Config, dry_run: bool, passphrase_file: Optional[str],
+            **kwargs):
     if dry_run:
         kwargs["passphrase"] = None
     elif config.sign_encrypted_data:
-        kwargs["passphrase"] = getpass(
-            "Please enter your gpg private key password:")
+        kwargs["passphrase"] = get_passphrase_from_file_or_prompt(passphrase_file)
     else:
         kwargs["passphrase"] = None
     return workflows_encrypt(*args, config=config, dry_run=dry_run, **kwargs)
 
 
-@block("passphrase")
 @wraps(workflows_decrypt)
-def decrypt(*args, dry_run: bool, **kwargs):
+def decrypt(*args, dry_run: bool, passphrase_file: Optional[str], **kwargs):
     if dry_run:
         kwargs["passphrase"] = None
     else:
-        kwargs["passphrase"] = getpass(
-            "Please enter your gpg private key password:")
+        kwargs["passphrase"] = get_passphrase_from_file_or_prompt(passphrase_file)
     return workflows_decrypt(*args, dry_run=dry_run, **kwargs)
 
-@exception_to_message((UserError, FileNotFoundError))
+
+@exception_to_message((UserError, FileNotFoundError), logger)
 def transfer(files: List[str],
              *,
              connection: str = None,
@@ -105,14 +114,18 @@ def transfer(files: List[str],
 def load_config_check():
     cfg = load_config()
     if not cfg.offline and cfg.check_version:
-        exception_to_message()(check_version)(cfg.repo_url)
+        exception_to_message(logger=logger)(check_version)(cfg.repo_url)
     return cfg
 
 
 class Cli(Subcommands):
     description = __doc__.format(URL_READTHEDOCS, URL_GITLAB_ISSUES)
-    version = __version__
+    version = VERSION_WITH_DEPS
     config = load_config_check()
+    passphrase_override = dict(help="Instead of asking for passphrase, "
+                                    "read it from a file",
+                               name="passphrase-file",
+                               dest="passphrase_file")
     logger = logging.getLogger()
     add_rotating_file_handler_to_logger(logger,
                                         log_dir=config.log_dir,
@@ -146,7 +159,8 @@ class Cli(Subcommands):
                 "dry_run": dict(
                     help="Use this flag to perform checks on the data only."),
                 "compress": dict(
-                    help="Compress the inner tarball")
+                    help="Compress the inner tarball"),
+                "passphrase": passphrase_override
             }),
         Subcommand(
             decorate(transfer,
@@ -180,7 +194,8 @@ class Cli(Subcommands):
             overrides={
                 "output_dir": dict(help="Output directory", default=os.getcwd(), alias="-o"),
                 "decrypt_only": dict(help="Skip extraction"),
-                "dry_run": dict(help="Use this flag to perform checks on the data only")
+                "dry_run": dict(help="Use this flag to perform checks on the data only"),
+                "passphrase": passphrase_override
             }
         ),
         SubcommandGroup("config",
@@ -203,7 +218,8 @@ class Cli(Subcommands):
             decorate(
                 request_sigs,
                 partial(
-                    portal_pgpkey_endpoint_url=config.dcc_portal_pgpkey_endpoint_url)
+                    portal_pgpkey_endpoint_url=config.dcc_portal_pgpkey_endpoint_url,
+                    gpg_store=config.gpg_store)
             ),
             overrides={
                 "key_ids": dict(help="Key ids to request signatures for")
@@ -217,7 +233,7 @@ class Cli(Subcommands):
                     gpg_store=config.gpg_store)
             ),
             overrides={
-                "keys": dict(help="Key ids to upload")
+                "key_ids": dict(help="Key ids to upload")
             }
         )
     )
