@@ -6,7 +6,7 @@ from .model import user_is_authorized_for_project
 from .error import UserError
 
 # Reexports
-AlnumStr = _metadata.AlnumStr
+alnum_str = _metadata.alnum_str
 ProjectIdStr = _metadata.ProjectIdStr
 METADATA_FILE = _metadata.METADATA_FILE
 
