@@ -5,12 +5,13 @@ import sys
 import logging
 from PySide2.QtWidgets import QApplication
 
-from . import app
+from . import main_window
 from ..utils.log import add_rotating_file_handler_to_logger
 
+
 def run():
     application = QApplication(sys.argv)
-    window = app.MainWindow()
+    window = main_window.MainWindow()
     logger = logging.getLogger()
     add_rotating_file_handler_to_logger(logger,
                 log_dir=window.app_data.config.log_dir,
