@@ -10,7 +10,7 @@ from dataclasses import dataclass
 
 from libbiomedit.lib.deserialize import deserialize
 
-from .log import exception_to_message, get_default_log_dir
+from .log import exception_to_message, get_default_log_dir, create_logger
 from ..core.model import Project
 from ..core.crypt import open_gpg_dir, get_default_gpg_config_dir
 from ..core.error import UserError
@@ -26,6 +26,8 @@ conf_sub_dir_by_os = {
     "Windows": ("AppData", "Roaming")
 }
 
+logger = create_logger(__name__)
+
 
 @dataclass(frozen=True)
 class Connection:
@@ -57,6 +59,7 @@ class Config:
     temp_dir: str = TMP_DIR
     ssh_password_encoding: str = "utf_8"
     default_sender: Optional[str] = None
+    gui_quit_confirmation: bool = True
 
     @property
     def dcc_portal_endpoint_url(self) -> str:
@@ -73,10 +76,10 @@ class Config:
 
     @property
     def gpg_store(self):
-        return exception_to_message(UserError)(open_gpg_dir)(self.gpg_config_dir)
+        return exception_to_message(UserError, logger)(open_gpg_dir)(self.gpg_config_dir)
 
 
-@exception_to_message()
+@exception_to_message(logger=logger)
 def load_config() -> Config:
     """Loads the config, returning a Config object"""
 
