@@ -3,6 +3,7 @@ import json
 from pathlib import Path
 from typing import List, Optional, Callable
 
+from . import workflow
 from ..utils.config import Config
 from ..utils.log import create_logger
 from ..core.archive import write_tar, ArchiveInMemoryFile, ArchiveFile, \
@@ -15,13 +16,13 @@ from ..core.crypt import retrieve_keys, encrypt_and_sign_file, \
     detach_sign_file, check_password
 from ..core.checksum import compute_checksum_sha256, write_checksums
 from ..core.error import UserError
-from ..core.metadata import MetaData, AlnumStr, ProjectIdStr
+from ..core.metadata import MetaData, alnum_str, ProjectIdStr
 from ..utils.progress import ProgressInterface, subprogress, \
     progress_file_iter, with_progress
 
 DATE_FMT_FILENAME = "%Y%m%dT%H%M%S"
 logger = create_logger(__name__)
-output_name_str = AlnumStr(min_length=1, max_length=50, allow_dots=True)
+output_name_str = alnum_str(min_length=1, max_length=50, allow_dots=True)
 
 
 def get_project(project_id, config):
@@ -71,7 +72,7 @@ def check_arg_value(arg_value: str,
 
 
 # pylint: disable=too-many-statements
-@logger.exception_to_message((UserError, FileNotFoundError, PermissionError))
+@workflow(logger, (UserError, FileNotFoundError, PermissionError))
 def encrypt(files: List[str],
             *,
             project_id: str,
@@ -86,6 +87,7 @@ def encrypt(files: List[str],
             progress: ProgressInterface = None) -> None:
     """Compress and encrypt files and/or directories.
     """
+
     if sender is None:
         sender = config.default_sender or config.gpg_store.default_key()
         if sender is None:
@@ -130,6 +132,7 @@ def encrypt(files: List[str],
             sender=sender,
             recipients=recipient,
             validation_keyid=config.key_validation_authority_keyid,
+            keyserver_url=config.keyserver_url,
             with_refresh_keys=not offline)
         logger.info('found the following keys:\n%s\n%s',
                     f'sender key: {sender_pub_key.uids[0]}, '
